# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListTextbookAssistantBooksRequest(DaraModel):
    def __init__(
        self,
        auth_token: str = None,
        book_id: str = None,
        grade: str = None,
        max_results: str = None,
        page: str = None,
        version: str = None,
        volume: str = None,
    ):
        # This parameter is required.
        self.auth_token = auth_token
        self.book_id = book_id
        self.grade = grade
        self.max_results = max_results
        self.page = page
        self.version = version
        self.volume = volume

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_token is not None:
            result['authToken'] = self.auth_token

        if self.book_id is not None:
            result['bookId'] = self.book_id

        if self.grade is not None:
            result['grade'] = self.grade

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.page is not None:
            result['page'] = self.page

        if self.version is not None:
            result['version'] = self.version

        if self.volume is not None:
            result['volume'] = self.volume

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('authToken') is not None:
            self.auth_token = m.get('authToken')

        if m.get('bookId') is not None:
            self.book_id = m.get('bookId')

        if m.get('grade') is not None:
            self.grade = m.get('grade')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('page') is not None:
            self.page = m.get('page')

        if m.get('version') is not None:
            self.version = m.get('version')

        if m.get('volume') is not None:
            self.volume = m.get('volume')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AliyunConsoleServiceInfoDTO(DaraModel):
    def __init__(
        self,
        buy_url: str = None,
        document_url: str = None,
        free_concurrency_count: int = None,
        free_count: int = None,
        service_code: str = None,
        service_name: str = None,
    ):
        self.buy_url = buy_url
        self.document_url = document_url
        self.free_concurrency_count = free_concurrency_count
        self.free_count = free_count
        self.service_code = service_code
        self.service_name = service_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.buy_url is not None:
            result['buyUrl'] = self.buy_url

        if self.document_url is not None:
            result['documentUrl'] = self.document_url

        if self.free_concurrency_count is not None:
            result['freeConcurrencyCount'] = self.free_concurrency_count

        if self.free_count is not None:
            result['freeCount'] = self.free_count

        if self.service_code is not None:
            result['serviceCode'] = self.service_code

        if self.service_name is not None:
            result['serviceName'] = self.service_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('buyUrl') is not None:
            self.buy_url = m.get('buyUrl')

        if m.get('documentUrl') is not None:
            self.document_url = m.get('documentUrl')

        if m.get('freeConcurrencyCount') is not None:
            self.free_concurrency_count = m.get('freeConcurrencyCount')

        if m.get('freeCount') is not None:
            self.free_count = m.get('freeCount')

        if m.get('serviceCode') is not None:
            self.service_code = m.get('serviceCode')

        if m.get('serviceName') is not None:
            self.service_name = m.get('serviceName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class QueryProjectResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.QueryProjectResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.QueryProjectResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class QueryProjectResponseBodyData(DaraModel):
    def __init__(
        self,
        create_time: str = None,
        project_apps: List[main_models.QueryProjectResponseBodyDataProjectApps] = None,
        project_id: str = None,
        project_name: str = None,
        project_sdk: List[main_models.QueryProjectResponseBodyDataProjectSDK] = None,
        project_type: str = None,
    ):
        self.create_time = create_time
        self.project_apps = project_apps
        self.project_id = project_id
        self.project_name = project_name
        self.project_sdk = project_sdk
        self.project_type = project_type

    def validate(self):
        if self.project_apps:
            for v1 in self.project_apps:
                 if v1:
                    v1.validate()
        if self.project_sdk:
            for v1 in self.project_sdk:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        result['ProjectApps'] = []
        if self.project_apps is not None:
            for k1 in self.project_apps:
                result['ProjectApps'].append(k1.to_map() if k1 else None)

        if self.project_id is not None:
            result['ProjectId'] = self.project_id

        if self.project_name is not None:
            result['ProjectName'] = self.project_name

        result['ProjectSDK'] = []
        if self.project_sdk is not None:
            for k1 in self.project_sdk:
                result['ProjectSDK'].append(k1.to_map() if k1 else None)

        if self.project_type is not None:
            result['ProjectType'] = self.project_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        self.project_apps = []
        if m.get('ProjectApps') is not None:
            for k1 in m.get('ProjectApps'):
                temp_model = main_models.QueryProjectResponseBodyDataProjectApps()
                self.project_apps.append(temp_model.from_map(k1))

        if m.get('ProjectId') is not None:
            self.project_id = m.get('ProjectId')

        if m.get('ProjectName') is not None:
            self.project_name = m.get('ProjectName')

        self.project_sdk = []
        if m.get('ProjectSDK') is not None:
            for k1 in m.get('ProjectSDK'):
                temp_model = main_models.QueryProjectResponseBodyDataProjectSDK()
                self.project_sdk.append(temp_model.from_map(k1))

        if m.get('ProjectType') is not None:
            self.project_type = m.get('ProjectType')

        return self

class QueryProjectResponseBodyDataProjectSDK(DaraModel):
    def __init__(
        self,
        create_time: str = None,
        demo_url: str = None,
        deploy_mode: str = None,
        develop_language: str = None,
        doc_url: str = None,
        sdk_name: str = None,
        sdk_url: str = None,
        sdk_version: str = None,
    ):
        self.create_time = create_time
        self.demo_url = demo_url
        self.deploy_mode = deploy_mode
        self.develop_language = develop_language
        self.doc_url = doc_url
        self.sdk_name = sdk_name
        self.sdk_url = sdk_url
        self.sdk_version = sdk_version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        if self.demo_url is not None:
            result['DemoUrl'] = self.demo_url

        if self.deploy_mode is not None:
            result['DeployMode'] = self.deploy_mode

        if self.develop_language is not None:
            result['DevelopLanguage'] = self.develop_language

        if self.doc_url is not None:
            result['DocUrl'] = self.doc_url

        if self.sdk_name is not None:
            result['SdkName'] = self.sdk_name

        if self.sdk_url is not None:
            result['SdkUrl'] = self.sdk_url

        if self.sdk_version is not None:
            result['SdkVersion'] = self.sdk_version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        if m.get('DemoUrl') is not None:
            self.demo_url = m.get('DemoUrl')

        if m.get('DeployMode') is not None:
            self.deploy_mode = m.get('DeployMode')

        if m.get('DevelopLanguage') is not None:
            self.develop_language = m.get('DevelopLanguage')

        if m.get('DocUrl') is not None:
            self.doc_url = m.get('DocUrl')

        if m.get('SdkName') is not None:
            self.sdk_name = m.get('SdkName')

        if m.get('SdkUrl') is not None:
            self.sdk_url = m.get('SdkUrl')

        if m.get('SdkVersion') is not None:
            self.sdk_version = m.get('SdkVersion')

        return self

class QueryProjectResponseBodyDataProjectApps(DaraModel):
    def __init__(
        self,
        application_access_ids: List[main_models.QueryProjectResponseBodyDataProjectAppsApplicationAccessIds] = None,
        id: str = None,
        project_id: str = None,
    ):
        self.application_access_ids = application_access_ids
        self.id = id
        self.project_id = project_id

    def validate(self):
        if self.application_access_ids:
            for v1 in self.application_access_ids:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['ApplicationAccessIds'] = []
        if self.application_access_ids is not None:
            for k1 in self.application_access_ids:
                result['ApplicationAccessIds'].append(k1.to_map() if k1 else None)

        if self.id is not None:
            result['Id'] = self.id

        if self.project_id is not None:
            result['ProjectId'] = self.project_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.application_access_ids = []
        if m.get('ApplicationAccessIds') is not None:
            for k1 in m.get('ApplicationAccessIds'):
                temp_model = main_models.QueryProjectResponseBodyDataProjectAppsApplicationAccessIds()
                self.application_access_ids.append(temp_model.from_map(k1))

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('ProjectId') is not None:
            self.project_id = m.get('ProjectId')

        return self

class QueryProjectResponseBodyDataProjectAppsApplicationAccessIds(DaraModel):
    def __init__(
        self,
        application_access_id: str = None,
        application_access_secret: str = None,
    ):
        self.application_access_id = application_access_id
        self.application_access_secret = application_access_secret

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_access_id is not None:
            result['applicationAccessId'] = self.application_access_id

        if self.application_access_secret is not None:
            result['applicationAccessSecret'] = self.application_access_secret

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationAccessId') is not None:
            self.application_access_id = m.get('applicationAccessId')

        if m.get('applicationAccessSecret') is not None:
            self.application_access_secret = m.get('applicationAccessSecret')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ExecuteTextbookAssistantGrammarCheckRequest(DaraModel):
    def __init__(
        self,
        auth_token: str = None,
        chat_id: str = None,
        scenario: str = None,
        user: str = None,
    ):
        # This parameter is required.
        self.auth_token = auth_token
        # This parameter is required.
        self.chat_id = chat_id
        # This parameter is required.
        self.scenario = scenario
        # This parameter is required.
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_token is not None:
            result['authToken'] = self.auth_token

        if self.chat_id is not None:
            result['chatId'] = self.chat_id

        if self.scenario is not None:
            result['scenario'] = self.scenario

        if self.user is not None:
            result['user'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('authToken') is not None:
            self.auth_token = m.get('authToken')

        if m.get('chatId') is not None:
            self.chat_id = m.get('chatId')

        if m.get('scenario') is not None:
            self.scenario = m.get('scenario')

        if m.get('user') is not None:
            self.user = m.get('user')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UsageInfoDTO(DaraModel):
    def __init__(
        self,
        completion_tokens: int = None,
        image_count: int = None,
        prompt_tokens: int = None,
        total_tokens: int = None,
        video_count: int = None,
        video_duration: int = None,
    ):
        self.completion_tokens = completion_tokens
        self.image_count = image_count
        self.prompt_tokens = prompt_tokens
        self.total_tokens = total_tokens
        self.video_count = video_count
        self.video_duration = video_duration

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.completion_tokens is not None:
            result['completionTokens'] = self.completion_tokens

        if self.image_count is not None:
            result['imageCount'] = self.image_count

        if self.prompt_tokens is not None:
            result['promptTokens'] = self.prompt_tokens

        if self.total_tokens is not None:
            result['totalTokens'] = self.total_tokens

        if self.video_count is not None:
            result['videoCount'] = self.video_count

        if self.video_duration is not None:
            result['videoDuration'] = self.video_duration

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('completionTokens') is not None:
            self.completion_tokens = m.get('completionTokens')

        if m.get('imageCount') is not None:
            self.image_count = m.get('imageCount')

        if m.get('promptTokens') is not None:
            self.prompt_tokens = m.get('promptTokens')

        if m.get('totalTokens') is not None:
            self.total_tokens = m.get('totalTokens')

        if m.get('videoCount') is not None:
            self.video_count = m.get('videoCount')

        if m.get('videoDuration') is not None:
            self.video_duration = m.get('videoDuration')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateAccessWarrantRequest(DaraModel):
    def __init__(
        self,
        app_id: str = None,
        request_sign: str = None,
        timestamp: str = None,
        user_client_ip: str = None,
        user_id: str = None,
        warrant_available: int = None,
    ):
        self.app_id = app_id
        self.request_sign = request_sign
        self.timestamp = timestamp
        self.user_client_ip = user_client_ip
        self.user_id = user_id
        self.warrant_available = warrant_available

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_id is not None:
            result['appId'] = self.app_id

        if self.request_sign is not None:
            result['requestSign'] = self.request_sign

        if self.timestamp is not None:
            result['timestamp'] = self.timestamp

        if self.user_client_ip is not None:
            result['userClientIp'] = self.user_client_ip

        if self.user_id is not None:
            result['userId'] = self.user_id

        if self.warrant_available is not None:
            result['warrantAvailable'] = self.warrant_available

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('appId') is not None:
            self.app_id = m.get('appId')

        if m.get('requestSign') is not None:
            self.request_sign = m.get('requestSign')

        if m.get('timestamp') is not None:
            self.timestamp = m.get('timestamp')

        if m.get('userClientIp') is not None:
            self.user_client_ip = m.get('userClientIp')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        if m.get('warrantAvailable') is not None:
            self.warrant_available = m.get('warrantAvailable')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class CostQueryTrendDTO(DaraModel):
    def __init__(
        self,
        default_metric: str = None,
        granularity: str = None,
        metrics: List[main_models.MetricDefRespDTO] = None,
        points: List[main_models.TrendPointDTO] = None,
    ):
        self.default_metric = default_metric
        self.granularity = granularity
        self.metrics = metrics
        self.points = points

    def validate(self):
        if self.metrics:
            for v1 in self.metrics:
                 if v1:
                    v1.validate()
        if self.points:
            for v1 in self.points:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.default_metric is not None:
            result['defaultMetric'] = self.default_metric

        if self.granularity is not None:
            result['granularity'] = self.granularity

        result['metrics'] = []
        if self.metrics is not None:
            for k1 in self.metrics:
                result['metrics'].append(k1.to_map() if k1 else None)

        result['points'] = []
        if self.points is not None:
            for k1 in self.points:
                result['points'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('defaultMetric') is not None:
            self.default_metric = m.get('defaultMetric')

        if m.get('granularity') is not None:
            self.granularity = m.get('granularity')

        self.metrics = []
        if m.get('metrics') is not None:
            for k1 in m.get('metrics'):
                temp_model = main_models.MetricDefRespDTO()
                self.metrics.append(temp_model.from_map(k1))

        self.points = []
        if m.get('points') is not None:
            for k1 in m.get('points'):
                temp_model = main_models.TrendPointDTO()
                self.points.append(temp_model.from_map(k1))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class RequestLogListQry(DaraModel):
    def __init__(
        self,
        keyword: str = None,
        page: int = None,
        page_size: int = None,
        status: int = None,
    ):
        self.keyword = keyword
        self.page = page
        self.page_size = page_size
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.keyword is not None:
            result['keyword'] = self.keyword

        if self.page is not None:
            result['page'] = self.page

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('keyword') is not None:
            self.keyword = m.get('keyword')

        if m.get('page') is not None:
            self.page = m.get('page')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ExecuteAITeacherEnglishParaphraseChatMessageRequest(DaraModel):
    def __init__(
        self,
        chat_id: str = None,
        content: str = None,
        grade: int = None,
        question_id: str = None,
        question_info: str = None,
        response_mode: str = None,
        user_answer: str = None,
        user_id: str = None,
    ):
        self.chat_id = chat_id
        # This parameter is required.
        self.content = content
        self.grade = grade
        self.question_id = question_id
        # This parameter is required.
        self.question_info = question_info
        # This parameter is required.
        self.response_mode = response_mode
        # This parameter is required.
        self.user_answer = user_answer
        # This parameter is required.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.chat_id is not None:
            result['chatId'] = self.chat_id

        if self.content is not None:
            result['content'] = self.content

        if self.grade is not None:
            result['grade'] = self.grade

        if self.question_id is not None:
            result['questionId'] = self.question_id

        if self.question_info is not None:
            result['questionInfo'] = self.question_info

        if self.response_mode is not None:
            result['responseMode'] = self.response_mode

        if self.user_answer is not None:
            result['userAnswer'] = self.user_answer

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('chatId') is not None:
            self.chat_id = m.get('chatId')

        if m.get('content') is not None:
            self.content = m.get('content')

        if m.get('grade') is not None:
            self.grade = m.get('grade')

        if m.get('questionId') is not None:
            self.question_id = m.get('questionId')

        if m.get('questionInfo') is not None:
            self.question_info = m.get('questionInfo')

        if m.get('responseMode') is not None:
            self.response_mode = m.get('responseMode')

        if m.get('userAnswer') is not None:
            self.user_answer = m.get('userAnswer')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModelCreateCmd(DaraModel):
    def __init__(
        self,
        api_key: str = None,
        base_url: str = None,
        description: str = None,
        max_input_length: str = None,
        max_output_length: str = None,
        model_id: str = None,
        model_type: str = None,
        name: str = None,
        symbol: str = None,
        tags: str = None,
    ):
        self.api_key = api_key
        self.base_url = base_url
        self.description = description
        self.max_input_length = max_input_length
        self.max_output_length = max_output_length
        self.model_id = model_id
        self.model_type = model_type
        self.name = name
        self.symbol = symbol
        self.tags = tags

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.api_key is not None:
            result['apiKey'] = self.api_key

        if self.base_url is not None:
            result['baseUrl'] = self.base_url

        if self.description is not None:
            result['description'] = self.description

        if self.max_input_length is not None:
            result['maxInputLength'] = self.max_input_length

        if self.max_output_length is not None:
            result['maxOutputLength'] = self.max_output_length

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.name is not None:
            result['name'] = self.name

        if self.symbol is not None:
            result['symbol'] = self.symbol

        if self.tags is not None:
            result['tags'] = self.tags

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('apiKey') is not None:
            self.api_key = m.get('apiKey')

        if m.get('baseUrl') is not None:
            self.base_url = m.get('baseUrl')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('maxInputLength') is not None:
            self.max_input_length = m.get('maxInputLength')

        if m.get('maxOutputLength') is not None:
            self.max_output_length = m.get('maxOutputLength')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('symbol') is not None:
            self.symbol = m.get('symbol')

        if m.get('tags') is not None:
            self.tags = m.get('tags')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class PersonalizedTextToImageAddInferenceJobResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.PersonalizedTextToImageAddInferenceJobResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.PersonalizedTextToImageAddInferenceJobResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class PersonalizedTextToImageAddInferenceJobResponseBodyData(DaraModel):
    def __init__(
        self,
        create_time: str = None,
        id: str = None,
        job_status: str = None,
        job_train_progress: float = None,
        model_id: str = None,
        prompt_id: str = None,
        result_image_url: List[str] = None,
    ):
        self.create_time = create_time
        self.id = id
        self.job_status = job_status
        self.job_train_progress = job_train_progress
        self.model_id = model_id
        # promptId
        self.prompt_id = prompt_id
        self.result_image_url = result_image_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.id is not None:
            result['id'] = self.id

        if self.job_status is not None:
            result['jobStatus'] = self.job_status

        if self.job_train_progress is not None:
            result['jobTrainProgress'] = self.job_train_progress

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.prompt_id is not None:
            result['promptId'] = self.prompt_id

        if self.result_image_url is not None:
            result['resultImageUrl'] = self.result_image_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('jobStatus') is not None:
            self.job_status = m.get('jobStatus')

        if m.get('jobTrainProgress') is not None:
            self.job_train_progress = m.get('jobTrainProgress')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('promptId') is not None:
            self.prompt_id = m.get('promptId')

        if m.get('resultImageUrl') is not None:
            self.result_image_url = m.get('resultImageUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModelMetricsDTO(DaraModel):
    def __init__(
        self,
        avg_response_time: float = None,
        input_tokens: int = None,
        output_tokens: int = None,
        success_rate: float = None,
        total_calls: int = None,
    ):
        self.avg_response_time = avg_response_time
        self.input_tokens = input_tokens
        self.output_tokens = output_tokens
        self.success_rate = success_rate
        self.total_calls = total_calls

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_response_time is not None:
            result['avgResponseTime'] = self.avg_response_time

        if self.input_tokens is not None:
            result['inputTokens'] = self.input_tokens

        if self.output_tokens is not None:
            result['outputTokens'] = self.output_tokens

        if self.success_rate is not None:
            result['successRate'] = self.success_rate

        if self.total_calls is not None:
            result['totalCalls'] = self.total_calls

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('avgResponseTime') is not None:
            self.avg_response_time = m.get('avgResponseTime')

        if m.get('inputTokens') is not None:
            self.input_tokens = m.get('inputTokens')

        if m.get('outputTokens') is not None:
            self.output_tokens = m.get('outputTokens')

        if m.get('successRate') is not None:
            self.success_rate = m.get('successRate')

        if m.get('totalCalls') is not None:
            self.total_calls = m.get('totalCalls')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Personalizedtxt2imgQueryImageAssetRequest(DaraModel):
    def __init__(
        self,
        encode_format: str = None,
        image_id: str = None,
        model_id: str = None,
        prompt_id: str = None,
    ):
        self.encode_format = encode_format
        # This parameter is required.
        self.image_id = image_id
        # This parameter is required.
        self.model_id = model_id
        # This parameter is required.
        self.prompt_id = prompt_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.encode_format is not None:
            result['encodeFormat'] = self.encode_format

        if self.image_id is not None:
            result['imageId'] = self.image_id

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.prompt_id is not None:
            result['promptId'] = self.prompt_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('encodeFormat') is not None:
            self.encode_format = m.get('encodeFormat')

        if m.get('imageId') is not None:
            self.image_id = m.get('imageId')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('promptId') is not None:
            self.prompt_id = m.get('promptId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ListTextbookAssistantBooksResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.ListTextbookAssistantBooksResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        # Id of the request
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.ListTextbookAssistantBooksResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class ListTextbookAssistantBooksResponseBodyData(DaraModel):
    def __init__(
        self,
        book_list: List[main_models.ListTextbookAssistantBooksResponseBodyDataBookList] = None,
        pagination_data: main_models.ListTextbookAssistantBooksResponseBodyDataPaginationData = None,
    ):
        self.book_list = book_list
        self.pagination_data = pagination_data

    def validate(self):
        if self.book_list:
            for v1 in self.book_list:
                 if v1:
                    v1.validate()
        if self.pagination_data:
            self.pagination_data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['bookList'] = []
        if self.book_list is not None:
            for k1 in self.book_list:
                result['bookList'].append(k1.to_map() if k1 else None)

        if self.pagination_data is not None:
            result['paginationData'] = self.pagination_data.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.book_list = []
        if m.get('bookList') is not None:
            for k1 in m.get('bookList'):
                temp_model = main_models.ListTextbookAssistantBooksResponseBodyDataBookList()
                self.book_list.append(temp_model.from_map(k1))

        if m.get('paginationData') is not None:
            temp_model = main_models.ListTextbookAssistantBooksResponseBodyDataPaginationData()
            self.pagination_data = temp_model.from_map(m.get('paginationData'))

        return self

class ListTextbookAssistantBooksResponseBodyDataPaginationData(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        max_results: int = None,
        total_count: int = None,
    ):
        self.current_page = current_page
        self.max_results = max_results
        self.total_count = total_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['currentPage'] = self.current_page

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('currentPage') is not None:
            self.current_page = m.get('currentPage')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListTextbookAssistantBooksResponseBodyDataBookList(DaraModel):
    def __init__(
        self,
        author: str = None,
        book_id: str = None,
        book_name: str = None,
        cover_image: str = None,
        edition: str = None,
        grade: str = None,
        impression: str = None,
        isbn: str = None,
        publisher: str = None,
        subject: str = None,
        version: str = None,
        volume: str = None,
    ):
        self.author = author
        self.book_id = book_id
        self.book_name = book_name
        self.cover_image = cover_image
        self.edition = edition
        self.grade = grade
        self.impression = impression
        self.isbn = isbn
        self.publisher = publisher
        self.subject = subject
        self.version = version
        self.volume = volume

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.author is not None:
            result['author'] = self.author

        if self.book_id is not None:
            result['bookId'] = self.book_id

        if self.book_name is not None:
            result['bookName'] = self.book_name

        if self.cover_image is not None:
            result['coverImage'] = self.cover_image

        if self.edition is not None:
            result['edition'] = self.edition

        if self.grade is not None:
            result['grade'] = self.grade

        if self.impression is not None:
            result['impression'] = self.impression

        if self.isbn is not None:
            result['isbn'] = self.isbn

        if self.publisher is not None:
            result['publisher'] = self.publisher

        if self.subject is not None:
            result['subject'] = self.subject

        if self.version is not None:
            result['version'] = self.version

        if self.volume is not None:
            result['volume'] = self.volume

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('author') is not None:
            self.author = m.get('author')

        if m.get('bookId') is not None:
            self.book_id = m.get('bookId')

        if m.get('bookName') is not None:
            self.book_name = m.get('bookName')

        if m.get('coverImage') is not None:
            self.cover_image = m.get('coverImage')

        if m.get('edition') is not None:
            self.edition = m.get('edition')

        if m.get('grade') is not None:
            self.grade = m.get('grade')

        if m.get('impression') is not None:
            self.impression = m.get('impression')

        if m.get('isbn') is not None:
            self.isbn = m.get('isbn')

        if m.get('publisher') is not None:
            self.publisher = m.get('publisher')

        if m.get('subject') is not None:
            self.subject = m.get('subject')

        if m.get('version') is not None:
            self.version = m.get('version')

        if m.get('volume') is not None:
            self.volume = m.get('volume')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ModelRouterQueryNacosProvidersResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.ModelRouterQueryNacosProvidersResponseBodyData] = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['data'].append(k1.to_map() if k1 else None)

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('data') is not None:
            for k1 in m.get('data'):
                temp_model = main_models.ModelRouterQueryNacosProvidersResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class ModelRouterQueryNacosProvidersResponseBodyData(DaraModel):
    def __init__(
        self,
        base_url: str = None,
        models: List[main_models.ModelRouterQueryNacosProvidersResponseBodyDataModels] = None,
        name: str = None,
        symbol: str = None,
    ):
        self.base_url = base_url
        self.models = models
        self.name = name
        self.symbol = symbol

    def validate(self):
        if self.models:
            for v1 in self.models:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.base_url is not None:
            result['baseUrl'] = self.base_url

        result['models'] = []
        if self.models is not None:
            for k1 in self.models:
                result['models'].append(k1.to_map() if k1 else None)

        if self.name is not None:
            result['name'] = self.name

        if self.symbol is not None:
            result['symbol'] = self.symbol

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('baseUrl') is not None:
            self.base_url = m.get('baseUrl')

        self.models = []
        if m.get('models') is not None:
            for k1 in m.get('models'):
                temp_model = main_models.ModelRouterQueryNacosProvidersResponseBodyDataModels()
                self.models.append(temp_model.from_map(k1))

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('symbol') is not None:
            self.symbol = m.get('symbol')

        return self

class ModelRouterQueryNacosProvidersResponseBodyDataModels(DaraModel):
    def __init__(
        self,
        extensions: main_models.ModelRouterQueryNacosProvidersResponseBodyDataModelsExtensions = None,
        identifier: str = None,
        in_out: str = None,
        input_token: str = None,
        output_token: str = None,
        type: str = None,
    ):
        self.extensions = extensions
        self.identifier = identifier
        self.in_out = in_out
        self.input_token = input_token
        self.output_token = output_token
        self.type = type

    def validate(self):
        if self.extensions:
            self.extensions.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.extensions is not None:
            result['extensions'] = self.extensions.to_map()

        if self.identifier is not None:
            result['identifier'] = self.identifier

        if self.in_out is not None:
            result['inOut'] = self.in_out

        if self.input_token is not None:
            result['inputToken'] = self.input_token

        if self.output_token is not None:
            result['outputToken'] = self.output_token

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('extensions') is not None:
            temp_model = main_models.ModelRouterQueryNacosProvidersResponseBodyDataModelsExtensions()
            self.extensions = temp_model.from_map(m.get('extensions'))

        if m.get('identifier') is not None:
            self.identifier = m.get('identifier')

        if m.get('inOut') is not None:
            self.in_out = m.get('inOut')

        if m.get('inputToken') is not None:
            self.input_token = m.get('inputToken')

        if m.get('outputToken') is not None:
            self.output_token = m.get('outputToken')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class ModelRouterQueryNacosProvidersResponseBodyDataModelsExtensions(DaraModel):
    def __init__(
        self,
        async_: bool = None,
    ):
        self.async_ = async_

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.async_ is not None:
            result['async'] = self.async_

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('async') is not None:
            self.async_ = m.get('async')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class TrendPointDTO(DaraModel):
    def __init__(
        self,
        timestamp: int = None,
        values: str = None,
    ):
        self.timestamp = timestamp
        self.values = values

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.timestamp is not None:
            result['timestamp'] = self.timestamp

        if self.values is not None:
            result['values'] = self.values

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('timestamp') is not None:
            self.timestamp = m.get('timestamp')

        if m.get('values') is not None:
            self.values = m.get('values')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class OralEvaluationStatisticsErrorCountRequest(DaraModel):
    def __init__(
        self,
        application_access_id: str = None,
        end_time: str = None,
        error_code: List[str] = None,
        granularity: str = None,
        project_id: str = None,
        start_time: str = None,
    ):
        # appId,appkey
        self.application_access_id = application_access_id
        self.end_time = end_time
        self.error_code = error_code
        self.granularity = granularity
        self.project_id = project_id
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_access_id is not None:
            result['applicationAccessId'] = self.application_access_id

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.granularity is not None:
            result['granularity'] = self.granularity

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.start_time is not None:
            result['startTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationAccessId') is not None:
            self.application_access_id = m.get('applicationAccessId')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('granularity') is not None:
            self.granularity = m.get('granularity')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        return self

